// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KCHART_VERSION_H
#define KCHART_VERSION_H

#define KCHART_VERSION_STRING "2.8.0"
#define KCHART_VERSION_MAJOR 2
#define KCHART_VERSION_MINOR 8
#define KCHART_VERSION_PATCH 0
#define KCHART_VERSION ((2<<16)|(8<<8)|(0))

#endif
